package com.ruoyi.framework.recovery.service;

import java.util.List;
import com.ruoyi.framework.recovery.domain.RecStallCategory;

/**
 * 回收档口类型Service接口
 * 
 * @author jin
 * @date 2024-11-16
 */
public interface IRecStallCategoryService 
{
    /**
     * 查询回收档口类型
     * 
     * @param id 回收档口类型主键
     * @return 回收档口类型
     */
    public RecStallCategory selectRecStallCategoryById(Long id);

    /**
     * 查询回收档口类型列表
     * 
     * @param recStallCategory 回收档口类型
     * @return 回收档口类型集合
     */
    public List<RecStallCategory> selectRecStallCategoryList(RecStallCategory recStallCategory);

    /**
     * 新增回收档口类型
     * 
     * @param recStallCategory 回收档口类型
     * @return 结果
     */
    public int insertRecStallCategory(RecStallCategory recStallCategory);

    /**
     * 修改回收档口类型
     * 
     * @param recStallCategory 回收档口类型
     * @return 结果
     */
    public int updateRecStallCategory(RecStallCategory recStallCategory);

    /**
     * 批量删除回收档口类型
     * 
     * @param ids 需要删除的回收档口类型主键集合
     * @return 结果
     */
    public int deleteRecStallCategoryByIds(Long[] ids);

    /**
     * 删除回收档口类型信息
     * 
     * @param id 回收档口类型主键
     * @return 结果
     */
    public int deleteRecStallCategoryById(Long id);
}
